package com.hyperling.expensetracker

import androidx.compose.foundation.clickable
import androidx.compose.foundation.horizontalScroll
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.rememberScrollState
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Add
import androidx.compose.material.icons.filled.Delete
import androidx.compose.material3.FloatingActionButton
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.RadioButton
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp

fun getEnumStringResourceID(enumName: String): Int {
    return (
            when (enumName) {
                SortType.NAME.toString() -> R.string.NAME
                SortType.COST.toString() -> R.string.COST
                SortType.RATE.toString() -> R.string.RATE
                else -> 0
            }
    )
}

@Composable
fun ExpenseScreen(
    state: ExpenseState,
    onEvent: (ExpenseEvent) -> Unit
){
    Scaffold (
        floatingActionButton = {
            FloatingActionButton(onClick = {
                onEvent(ExpenseEvent.ShowDialog)
            }) {
                Icon(
                    imageVector = Icons.Default.Add,
                    contentDescription = "Add Expense",
                )
            }
        }
    ){ padding ->
        if(state.isAddingExpense){
            ExpenseScreenDialogAdd(state, onEvent)
        }

        LazyColumn (
            contentPadding = padding,
            modifier = Modifier.fillMaxSize(),
            verticalArrangement = Arrangement.spacedBy(16.dp)
        ){
            item {
                Row (){
                    Text(text = "Sort ascending by:")
                }
                Row (
                    modifier = Modifier
                        .fillMaxWidth()
                        .horizontalScroll(rememberScrollState()),
                    verticalAlignment = Alignment.CenterVertically
                ){
                    SortType.values().forEach { sortType ->
                        Row (
                            modifier = Modifier
                                .clickable {
                                    onEvent(ExpenseEvent.SortExpenses(sortType))
                                },
                            verticalAlignment = Alignment.CenterVertically
                        ){
                            RadioButton(
                                selected = state.sortType == sortType,
                                onClick = {
                                    onEvent(ExpenseEvent.SortExpenses(sortType))
                                }
                            )
                            Text(text = stringResource(getEnumStringResourceID(sortType.name)))
                        }
                    }
                }
                Row (){
                    Text(text = "Expenses:")
                }
            }
            items(state.expenses) {expense ->
                Row (
                    modifier = Modifier.fillMaxWidth()
                ) {
                    Column (
                        modifier = Modifier.weight(1f)
                    ) {
                        Text (
                            text = expense.name,
                            fontSize = 20.sp
                        )
                        Text(
                            text = "${expense.cost} per ${expense.rate}",
                            fontSize = 12.sp
                        )
                    }
                    IconButton(onClick = {
                        onEvent(ExpenseEvent.DeleteExpense(expense))
                    }) {
                        Icon(
                            imageVector = Icons.Default.Delete,
                            contentDescription = "Delete Expense"
                        )
                    }
                }
            }
        }
    }
}